#pragma rtGlobals=1		// Use modern global access method.

//This macro requires 2006GeneralMacros
// TO USE, CHANGE ALL LINES CONTAINING THE COMMENT "EDIT ME", THEN SAVE PROCEDURE, OR COPY PROCEDURE INTO YOUR IGOR EXPERIMENT. 
//ASSUME THAT AOCTIMEWAVE AND ALL DATA WAVES ARE LOADED BEFORE RUNNING MACRO.

macro MakeIcarttFile(ictFlDate, ictRevDate, rev, platform)	//flight date and revision date
	string ictFlDate, ictRevDate=Time2yyyymmddhhmmss(datetime)[0,7], rev, platform	//get today's date as default for revision date
	prompt ictFlDate, "Enter the date of beginning of data: (yyyymmdd)"
	prompt ictRevDate, "Enter the date of data reduction or revision: (yyyymmdd)"
	prompt rev, "Enter revision letter (for field data) or number (for final data): "
	prompt platform, "Choose platform", popup, "P3;RHB;"

	variable dataStartVar
	Silent 1

//	Convert Time to just be seconds from midnight of this day.
	Duplicate/O AOCTimeWave, AOCTimeWaveConvert	//this DaqFactory time is seconds from 1970. Convert to seconds from midnight on flightdate
	dataStartVar = yyyymmddhhmmss2time(ictFlDate+"000000")	//Get the time in sec of start of data
	AOCTimeWaveConvert -= dataStartVar	//This is now seconds from midnight

	rev = UpperStr(rev)	//make sure Rev is Capital (no effect on numbers in string)
	writeICARTTformatFile(ictFlDate, ictRevDate, rev, platform)
end macro

function writeICARTTformatFile(ictFlDate, ictRevDate, rev, platform)
	string ictFlDate, ictRevDate, rev, platform
	
	string fname, ictFlyyyy, ictFlmm, ictFldd, ictRevyyyy, ictRevmm, ictRevdd, specialComments
	string wlist, wname, letters, numbers, revStr, revType, revComments, str
	variable refNum, numItems, i, numrows, numRevs
	wave AOCTimewaveConvert, AmbTemp, DewPtTemp, EquivPotTemp  //EDIT ME!!  CHANGE TO , DELIMITED LIST OF WAVES TO WRITE TO FILE, INCLUDING TIMEWAVE.
	
//	Replace NaN's with missing value for icartt file
	wlist = "AmbTemp;DewPtTemp;EquivPotTemp;" //EDIT ME!!  CHANGE TO ; DELIMITED LIST OF WAVES TO WRITE TO FILE. DON'T INCLUDE TIMEWAVE IN LIST
	numItems = ItemsInList(wlist, ";")
	for (i=0; i<numItems; i+=1)
		wname = StringFromList(i, wlist, ";")
		ChangeNans($wname, -9999)	//need $ because function expects a wave, not a string.
	endfor

	letters = "A;B;C;D;E;F;G;"
	numbers = "0;1;2;3;4;5;"

	if (FindListItem(rev, letters, ";")>=0)	//Check Rev number or letter
		revType = letters
	endif
	if (FindListItem(rev, numbers, ";")>=0)
		revType = numbers
	endif
	if (strlen(revType)==0)	//revType didn't get assigned above in one of the 2 cases.
		Abort "Either rev is out of range or bad value was entered. Rev = "+rev
	endif
	
	numRevs = WhichListItem(rev, revType, ";")
	if (numRevs!=-1)
		revComments = ""
		for (i=0; i<= numRevs; i+=1)
			revStr = "R"+StringFromList(numRevs-i, revType, ";")
			Prompt str, "Enter comments for "+revStr
			DoPrompt "Enter comments", str
			revComments += revStr+": "+str+"\r\n"
		endfor
	else
		Abort "Revision out of range or incorrect."
	endif

	specialComments = "N/A"
	Prompt specialComments, "Enter any special comments for the ICARTT file:"
	DoPrompt "Enter comments", specialComments

	if (V_flag==1)	//User clicked cancel in Prompt dialog
		Abort
	endif
	if (strlen(specialComments)==0)
		specialComments = "N/A"	//Don't want a blank line in the file, so if user deleted text, set it back to default
	endif

	fname = "AircraftMet_"+platform+"_"+ictFlDate+"_R"+rev+".ict"	//EDIT ME. CHANGE "AircraftMet" TO YOUR DATA NAME
	ictFlyyyy = ictFlDate[0,3]
	ictFlmm = ictFlDate[4,5]
	ictFldd = ictFlDate[6,7]

	ictRevyyyy = ictRevDate[0,3]
	ictRevmm = ictRevDate[4,5]
	ictRevdd = ictRevDate[6,7]
	
	numrows = 33 + numItems + numRevs	//calculate # of rows of header. Gets written into top of file. numItems is # of waves to write

//Use either of the next 2 lines to set the path for where the ICARTT file will be saved. Hard-coded, or user selects folder.

	NewPath/M="Select folder to save ICARTT file in."/O ictPath	//EDIT ME. CHANGE PATH TO SAVE FILE TO.
//	NewPath/C/O ictPath, "Macintosh HD:Users:kaikin:Documents:2006TexAQS AOC Data:Data_ict:flt"+ictFlDate	//EDIT ME. CHANGE PATH TO SAVE FILE TO.

	Open/P=ictPath/T="TEXT"/C="IGR0" refNum as fname
	fprintf refNum, "%d 1001\r\n", numrows						//# of rows and file format
	fprintf refNum, "Gerd Hubler\r\n"								//PI name.		EDIT ME. 
	fprintf refNum, "NOAA ESRL Chemical Sciences Division\r\n"	//Organization	EDIT ME. 
	fprintf refNum, "various aircraft sensors\r\n"					//Instrument	EDIT ME. 
	fprintf refNum, "2006 TexAQS\r\n"								//mission name
	fprintf refNum, "1 1\r\n"										//Volume #, # of files
	fprintf refNum, "%s %s %s %s %s %s\r\n", ictFlyyyy, ictFlmm, ictFldd, ictRevyyyy, ictRevmm, ictRevdd	//flight date and revision date
	fprintf refNum, "1\r\n"										//Data interval (1 for 1Hz data)
	fprintf refNum, "AOCTimewave\r\n"								//Independent valiable name		//EDIT ME IF NOT USING AICTimeWave
	fprintf refNum, "%d\r\n", numItems							//# of dependent variables (columns of data)
	fprintf refNum, "1 1 1\r\n"									//Scale factors	EDIT ME. (Put in correct value and number of factors)
	fprintf refNum, "-9999 -9999 -9999\r\n"					//Missing value indicator. EDIT ME. (Put in correct value and number of factors)
	fprintf refNum, "AmbTemp\r\n"								//wave names. EDIT ME.
	fprintf refNum, "DewPtTemp\r\n"								//EDIT ME. ADD LINES OR DELETE AS NEEDED.
	fprintf refNum, "EquivPotTemp\r\n"							//EDIT ME.  ADD LINES OR DELETE AS NEEDED.
	fprintf refNum, "1\r\n"										//# of special comment lines NOT including this line
	fprintf refNum, "SPECIAL COMMENTS:"+specialComments+"\r\n"	//special comments
	fprintf refNum, "%d \r\n", 18 + numRevs 							//# of normal comment lines
	fprintf refNum, "PI_CONTACT_INFO: Address: NOAA ESRL Chemical Sciences Division, Mail Stop R/CSD7, 325 Broadway, Boulder, CO 80305\r\n"	//EDIT ME.
	fprintf refNum, "PLATFORM: NOAA WP-3D\r\n"		//EDIT ME.
	fprintf refNum, "LOCATION: The aircraft was stationed in Houston, Texas. Aircraft location information in AircraftPosition file.\r\n"	//EDIT ME
	fprintf refNum, "ASSOCIATED_DATA: N/A\r\n"
	fprintf refNum, "INSTRUMENT_INFO: N/A\r\n"
	fprintf refNum, "DATA_INFO: Units:AmbTemp C; DewPtTemp C; EquivPotTemp K; \r\n"	//EDIT ME. ENTER WAVENAME AND UNITS
	fprintf refNum, "UNCERTAINTY: N/A\r\n"			//EDIT ME. 
	fprintf refNum, "ULOD_FLAG: -7777\r\n"
	fprintf refNum, "ULOD_VALUE: N/A\r\n"
	fprintf refNum, "LLOD_FLAG: -8888\r\n"
	fprintf refNum, "LLOD_VALUE: N/A\r\n"
	fprintf refNum, "DM_CONTACT_INFO: Data Manager:Ken Aikin; email:Kenneth.C.Aikin@noaa.gov\r\n"
	fprintf refNum, "PROJECT_INFO: TexAQS 2006 Study; July 27 - Oct 13, 2006\r\n"
	fprintf refNum, "STIPULATIONS_ON_USE: Use of these data require prior ok from PI.\r\n"
	fprintf refNum, "OTHER_COMMENTS:       None\r\n"								//EDIT ME. CHANGE "NONE" TO COMMENT IF ANY
	fprintf refNum, "REVISION: "+rev+"\r\n"										//Gets set from prompts above
	fprintf refNum, revComments	// Preliminary Data.  For in-field use.\r\n"		//Gets set from prompts above
	fprintf refNum, "AOCTimewave %s\r\n", ReplaceString(";", wlist, " " )  //EDIT ME IF NOT USING AOCTimewave. (Replaces ";" with " " in wlist. ie AmbTemp DewPtTemp EquivPotTemp)
	
//	Done with header. Now write the waves to the file. Putting 0.xf into the format writes all digits to left of decimal.
	wfprintf refNum, "%7.1f %0.3f %0.3f %0.2f\r\n", AOCTimeWaveConvert, AmbTemp, DewPtTemp, EquivPotTemp	//EDIT ME. CHANGE FORMAT STATEMENTS AND WAVE NAMES
	Close refNum
	Print "Done writing ICARTT file."
	
//If desired, change the missing values from -9999 back to NaN
	for (i=0; i<numItems; i+=1)
		wname = StringFromList(i, wlist, ";")
		Change2Nans($wname, -9999)	//need $ because function expects a wave, not a string.
	endfor

end function
